Module pr_api

Module pr_api 

Functions

get_commit_check_runs
Fetch check runs for a specific commit ref.
get_commit_status
Fetch the combined commit status for a specific commit ref.
get_pr_commits
Fetch commits for a PR.
get_pr_files
Fetch the list of changed files for a PR.
get_pr_metadata
Fetch PR metadata.
get_pr_reviews
Fetch reviews for a PR (paginated).
list_recent_merged_prs
Fetch recent merged PRs for a repository from the closed PR listing.
search_merged_prs
Search for merged PRs within a date range using GitHub Search API.
search_merged_prs_in_range
Search for merged PRs within a PR number range using GitHub Search API.