pub fn get_commit_status(
client: &GitHubClient,
owner: &str,
repo: &str,
git_ref: &str,
) -> Result<CombinedStatusResponse>Expand description
Fetch the combined commit status for a specific commit ref.
pub fn get_commit_status(
client: &GitHubClient,
owner: &str,
repo: &str,
git_ref: &str,
) -> Result<CombinedStatusResponse>Fetch the combined commit status for a specific commit ref.