parse_range

Function parse_range 

pub fn parse_range(arg: &str) -> Option<RangeSpec>
Try to parse a range specification from a CLI argument. Returns None if the argument is not a range (e.g., a plain PR number).