Structs
- GitHub
Commit Pull Association - Associates a commit SHA with the pull requests that introduced it.
Functions
- build_
pull_ request_ bundle - Builds an evidence bundle from a single pull request’s metadata and reviews.
- build_
release_ bundle - Builds an evidence bundle from a release tag comparison and associated commits.
- map_
build_ platform_ evidence - Maps check run evidence into build platform evidence.
- map_
check_ runs_ evidence - Maps GitHub check run items and combined commit statuses into platform-neutral evidence.
- map_
promotion_ batch_ evidence - Converts a GitHub tag comparison into a platform-neutral
PromotionBatch. - map_
pull_ request_ evidence - Converts GitHub PR data into a platform-neutral
GovernedChange.