Functions
- get_
commit_ check_ runs - Fetch check runs for a specific commit ref.
- get_
commit_ status - Fetch the combined commit status for a specific commit ref.
- get_
pr_ commits - Fetch commits for a PR.
- get_
pr_ files - Fetch the list of changed files for a PR.
- get_
pr_ metadata - Fetch PR metadata.
- get_
pr_ reviews - Fetch reviews for a PR (paginated).
- list_
recent_ merged_ prs - Fetch recent merged PRs for a repository from the closed PR listing.
- search_
merged_ prs - Search for merged PRs within a date range using GitHub Search API.
- search_
merged_ prs_ in_ range - Search for merged PRs within a PR number range using GitHub Search API.